cd "u:\Stata_long\"
log using riesbymu.log, replace
infile  id hamd intcpt week endog endweek using RIESBY.DAT.txt, clear
* remove observations with missing hamd 
drop if mi(hamd)
summarize

* random intercept model
mixed hamd week  || id: , mle

* random intercept and trend model
mixed hamd week  || id: week, covariance(unstructured) mle

* obtain the random effects for each subject
predict u1 u0, reffects

* list the random effects for the first few subjects
by id, sort: generate tolist = (_n==1)
list id u0 u1 in 1/30 if tolist

* add random and fixed effects together, list out a few
generate intercept = _b[_cons] + u0
generate slope = _b[week] + u1
list id intercept slope in 1/30 if tolist

* plot subjects intercepts and slopes
local yref = _b[_cons]
local xref = _b[week]
twoway scatter intercept slope, yline(`yref', lpattern(dash)) ///
       xline(`xref', lpattern(dash)) 

* generate an estimated spaghetti plot
predict fithamd, fitted
sort id week
twoway connected fithamd week, connect(L)

* residual plot
predict resids, residuals
twoway histogram resids 


* model with endog & endweek 
mixed hamd week endog endweek  || id: week, covariance(unstructured) mle
lincom endog + 5*endweek

* model with just endog & week 
mixed hamd week endog   || id: week, covariance(unstructured) mle

* model with quadratic effect of week
generate week2 = week*week
mixed hamd week week2 || id: week week2, covariance(unstructured) mle stddev

* generate an estimated spaghetti plot (quadratic model)
predict fithamd_quad, fitted
sort id week
twoway connected fithamd_quad week, connect(L)

* model with fixed quadratic effect of week (not random)
mixed hamd week week2 || id: week, covariance(unstructured) mle
log close
